#!/usr/bin/env python3
#  Copyright 2020  Dominik Sekotill <dom.sekotill@kodo.org.uk>
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

"""
Check if the given files contain a copyright notice mentioning the current year
"""

import re
import sys
import time
from subprocess import check_output


def check_file(path: str) -> bool:
	"""
	Check for an up-to-date copyright notice in the first few lines of the given file
	"""
	with open(path) as file:
		lines = file.read(512)
	year = time.strftime('%Y')
	return bool(re.search(f'\\b(?:copyright)\\b.*\\b{year}\\b', lines, re.I))


def main():
	"""
	CLI entrypoint
	"""
	cmd = ['git', '--no-pager', 'diff', '--no-commit-id', '--name-only', '-r']
	changed = set(check_output(cmd, text=True).splitlines())
	missing = []

	for path in sys.argv[1:]:
		if path not in changed:
			continue
		if not check_file(path):
			missing.append(path)

	if missing:
		writer = sys.stderr.write
		writer("The following files are missing an up-to-date copyright notice:\n")
		for path in missing:
			writer(f"  {path}\n")
		sys.exit(1)


if __name__ == '__main__':
	main()
